# coding: utf-8

"""
    XRELY

    API Documentation for XRELY platform  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: contact@xrely.com
    
"""


from __future__ import absolute_import

import unittest

import xrely_lib_client
from xrely_lib_client.models.filter_field import FilterField  # noqa: E501
from xrely_lib_client.rest import ApiException


class TestFilterField(unittest.TestCase):
    """FilterField unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFilterField(self):
        """Test FilterField"""
        # FIXME: construct object with mandatory attributes with example values
        # model = xrely_lib_client.models.filter_field.FilterField()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
